#include <hmg.ch>

function html_init( cHTMLFile, cHeader, nTopMargin, nLeftMargin, nRightMargin, nBottomMargin, cFontName, nFontSize )
   local oFile := nil
   local cHTML := ''
   default cHTMLFile := ''
   default nTopMargin := 20.0
   default nLeftMargin := 20.0
   default nRightMargin := 20.0
   default nBottomMargin := 20.0
   default cHeader := ''
   default cFontName := 'Arial'
   default nFontSize := 10
   
   if hmg_len( alltrim( cHTMLFile ) ) == 0
      cHTMLFile := alltrim( PutFile ( { { "HTML Files (*.html)","*.html"}} , "Save..." ,  , .f. ) )
      if hmg_len( cHTMLFile ) == 0
         return nil
      endif
   endif   
   if hb_uat( ".html", hmg_lower( cHTMLFile ) ) > 0
      if .not. hb_uright( hmg_lower( cHTMLFile ), 5 ) == ".html"
         cHTMLFile := cHTMLFile + ".html"
      endif
   else
      cHTMLFile := cHTMLFile + ".html"
   endif
   && if file( cHTMLFile )
      && if .not. msgyesno( cHTMLFile + ' - File already exists! Do you want to overwrite?' )
         && return nil
      && endif
   && endif
   oFile := fcreate( cHTMLFile )
   if oFile < 0
      msgstop( "File "+ cHTMLFile + " could not be created!" )
      return nil
   endif
   if hmg_len( alltrim( cHeader ) ) == 0
      cHeader := 'HTML Report'
   endif
   cHTML := '<HTML>' + CRLF
   if hmg_len( cHeader ) > 0
      cHTML := cHTML + '<HEAD><TITLE>' + cHeader + '</TITLE></HEAD>' + CRLF
   endif
   cHTML := cHTML + '<STYLE>' + CRLF
   cHTML := cHTML + '.td1 { font-family:"' + cFontName + '", "Arial"; font-size:' + alltrim( str( nFontSize ) ) + 'pt; border-style:outset; border-width:0 }' + CRLF
   cHTML := cHTML + 'table { border-collapse: collapse }' + CRLF
   cHTML := cHTML + 'td, th { font-family:"' + cFontName + '", "Arial"; font-size:' + alltrim( str( nFontSize ) ) + 'pt; border-style:outset; border-width:1; padding: 2px }' + CRLF
   cHTML := cHTML + 'tr:hover {background-color: #f5f5f5}' + CRLF
   cHTML := cHTML + 'table-layout: fixed' + CRLF 
   cHTML := cHTML + '</STYLE>'
   cHTML := cHTML + '<BODY TOPMARGIN=' + alltrim( str( nTopMargin ) ) + ' LEFTMARGIN=' + alltrim( str( nLeftMargin ) ) + ' RIGHTMARGIN=' + alltrim( str( nRightMargin ) ) + ' BOTTOMMARGIN=' + alltrim( str( nBottomMargin ) ) + '>' + CRLF
   cHTML := cHTML + '<TABLE>' + CRLF
   if hmg_len( cHeader ) > 0
      cHTML := cHTML + '<TR><TD align="CENTER" class="TD1"><font size=4><u>' + cHeader + '</u></font></TD></TR>' + CRLF
   endif
   cHTML := cHTML + '</TABLE>' + CRLF
   
   fWrite( oFile, cHTML )   
   
return oFile


function html_para( oFile, cData )
   local cHTML := ''   
   default cData := ''
   cHTML := '<p>' + cData + '</p>' + CRLF
   fWrite( oFile, cHTML )   
   return nil

function html_table( cHeader, aTable, aColumnHeaders, aColumnWidths, aColumnJustify, aDataJustify, lColHeaders )
   local nTotalWidth := 0
   local cHTML := ''
   local nRows := 0
   local aLineData := {}
   local nColumnCount := 0
   local i := 0, j := 0
   local lDataJustify := .f.
   local cAlign := 'LEFT'
   
   default cHeader := ''
   default aColumnHeaders := {}
   default aColumnWidths := {}
   default aColumnJustify := {}
   default aDataJustify := {}
   if valtype( aTable ) == 'A'
      if hmg_len( aTable ) == 0
         return nil
      endif
   else   
      return nil
   endif
   if hmg_len( aDataJustify ) > 0
      lDataJustify := .t.
   endif
   nRows := hmg_len( aTable )
   nColumnCount := hmg_len( aColumnHeaders )
   for i := 1 to nColumnCount
      nTotalWidth := nTotalWidth + aColumnWidths[ i ] 
   next i
   
   // report headers table   
   && cHTML := cHTML + '<TABLE Width="' + alltrim( str( nTotalWidth ) ) + '">' + CRLF
   && if hmg_len( cHeader ) > 0
      && cHTML := cHTML + '<TR><TD align="CENTER" class="TD1"><font size=3><u>' + cHeader + '</u></font></TD></TR>' + CRLF
   && endif
   && cHTML := cHTML + '</TABLE>' + CRLF
   
   
   // Main Table
   
   cHTML := cHTML + '<TABLE Width="' + alltrim( str( nTotalWidth ) ) + '">' + CRLF
   
   // Column Headers
   if lColHeaders
      cHTML := cHTML + '<TR>' + CRLF
      for i := 1 to nColumnCount
         if aColumnWidths[ i ] > 0
            cAlign := if( aColumnJustify[ i ] == 1, 'RIGHT', if( aColumnJustify[ i ] == 2, 'CENTER', 'LEFT' ) )
            cHTML := cHTML + '<TD WIDTH=' + alltrim( str( aColumnWidths[ i ] ) ) + ' ALIGN="' + cAlign + '" border-width=0><B>' + aColumnHeaders[ i ] + '</B></TD>' + CRLF
         endif
      next i
      cHTML := cHTML + '</TR>' + CRLF
   endif   
   
   // Now it is time for data
   
   for i := 1 to nRows
      aLineData := aTable[ i ]
      cHTML := cHTML + '<TR>' + CRLF
      for j := 1 to nColumnCount
         if aColumnWidths[ j ] > 0
            cAlign := if( aColumnJustify[ j ] == 1, 'RIGHT', if( aColumnJustify[ j ] == 2, 'CENTER', 'LEFT' ) )
            if lDataJustify
               cAlign := if( aDataJustify[ i, j ] == 1, 'RIGHT', if( aDataJustify[ i, j ] == 2, 'CENTER', 'LEFT' ) )
            endif    
            if valtype( aLineData[ j ] ) == 'U'
               aLineData[ j ] := ''
            endif
            cHTML := cHTML + '<TD WIDTH=' + alltrim( str( aColumnWidths[ j ] ) ) + ' ALIGN="' + cAlign + '">' + aLineData[ j ] + '</TD>' + CRLF
         endif
      next j
      cHTML := cHTML + '</TR>' + CRLF
   next i
   cHTML := cHTML + '</TABLE>' + CRLF
   && fWrite( oFile, cHTML )   
   && html_para( oFile ) 
return cHTML

function html_close( oFile )   
   local cHtml := ''
   cHTML := cHTML + '</HTML>' + CRLF
   fWrite( oFile, cHTML )   
   if .not. fclose( oFile )
      msgstop( 'Error in Saving the Report!', 'Report Writer' )
   endif   
return nil

function html_grid( cGrid, cWindowName, oFile, cHeader )
   local aColumnHeaders := {}
   local aColumnWidths := {}
   local aColumnJustify := {}
   local aData := {}
   local nCols := 0
   local aDataJustify := {}
   local nRows := 0
   local i, j := 0
   default cHeader := ''
   
   nCols := getproperty( cWindowName, cGrid, 'COLUMNCOUNT' )
   for i := 1 to nCols
      aadd( aColumnHeaders, getproperty( cWindowName, cGrid, 'COLUMNHEADER', i ) )
      aadd( aColumnWidths, getproperty( cWindowName, cGrid, 'COLUMNWIDTH', i ) )
      aadd( aColumnJustify, getproperty( cWindowName, cGrid, 'COLUMNJUSTIFY', i ) )
   next i
   nRows := getproperty( cWindowName, cGrid, 'ITEMCOUNT' )
   for i := 1 to nRows
      aLineDAta := getproperty( cWindowName, cGrid, 'ITEM', i )
      aadd( aData, aclone( aLineData ) )
      aadd( aDataJustify, aclone( aColumnJustify ) )
      for j := 1 to hmg_len( aLineData )
         if aColumnJustify[ j ] == 0
            if hmg_len( aLineData[ j ] ) > hmg_len( alltrim( aLineData[ j ] ) ) .and. ( val( alltrim( aLineData[ j ] ) ) <> 0 .or. alltrim( aLineData[ j ] ) == '0' )
               // right aligned number text
               aDataJustify[ i, j ] :=  1
            endif   
         endif   
      next j
   next i
   html_table( oFile, cHeader, aData, aColumnHeaders, aColumnWidths, aColumnJustify, aDataJustify )
   return nil 
      
   